@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Courriel::Headers;
 use Courriel::Helpers qw( unique_boundary );
@@ -19,7 +19,7 @@ use DateTime::Format::Natural;
 use Email::Address;
 use Encode qw( encode );
 use List::AllUtils qw( uniq );
-use MooseX::Params::Validate 0.21 qw( validated_list );
+use Params::ValidationCompiler 0.18 qw( validation_for );
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -348,7 +348,12 @@ sub all_parts_matching {
 }
 
 {
-    my @spec = ( text => { isa => StringRef, coerce => 1 } );
+    my $validator = validation_for(
+        params => [
+            text => { type => StringRef },
+        ],
+        named_to_list => 1,
+    );
 
     # This is needed for Email::Abstract compatibility but it's a godawful
     # idea, and even Email::Abstract says not to do this.
@@ -356,10 +361,7 @@ sub all_parts_matching {
     # It's much safer to just make a new Courriel object from scratch.
     sub replace_body {
         my $self = shift;
-        my ($text) = validated_list(
-            \@_,
-            @spec,
-        );
+        my ($text) = $validator->(@_);
 
         my $part = Courriel::Part::Single->new(
             headers         => $self->headers,
@@ -373,17 +375,17 @@ sub all_parts_matching {
 }
 
 {
-    my @spec = (
-        text         => { isa => StringRef, coerce  => 1 },
-        is_character => { isa => Bool,      default => 0 },
+    my $validator = validation_for(
+        params => [
+            text         => { type => StringRef },
+            is_character => { type => Bool, default => 0 },
+        ],
+        named_to_list => 1,
     );
 
     sub parse {
         my $class = shift;
-        my ( $text, $is_character ) = validated_list(
-            \@_,
-            @spec,
-        );
+        my ( $text, $is_character ) = $validator->(@_);
 
         if ($is_character) {
             ${$text} = encode( 'UTF-8', ${$text} );
@@ -522,7 +524,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -530,7 +532,7 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -790,7 +792,7 @@ changes.
 Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel>
 (or L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>).
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
 =head1 DONATIONS
 
@@ -833,7 +835,7 @@ Zbigniew Łukasiak <zzbbyy@gmail.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
